==> youtui-center-api-0.0.1.11-lichao1-20180725.124233-4-sources.jar: cn/com/duiba/tuia/youtui/center/api/dto/youtui/YoutuiCdkeyDto.java <==
package cn.com.duiba.tuia.youtui.center.api.dto.youtui;

import java.io.Serializable;
import java.util.Date;

/**
 *  趣晒的cdkey
 *  @author lichao 2018/7/24
 */
public class YoutuiCdkeyDto implements Serializable {

    //主键
    private Long id;

    //用户id
    private Long consumerId;

    //app使用的用户id
    private Long useConsumer;

    //内容id
    private Long contentId;

    //内容类型(0:活动 2:直投页 3:游戏)
    private Integer contentType;

    private Date gmtCreate;

    private Date gmtModified;

    private String extInfo;

    //cdkey邀请码
    private String cdkey;

    //cdkey所携带的金钱
    private Integer cdkeyMoney;

    //cdkey是否被使用过0否，1是
    private Integer cdkeyUsed;

    //cdkey的是否需要引导0 不需要引导 1需要引导
    private Integer cdkeyGuide;

    //cdkey的类型0 回流(不可重复使用)
    private Integer cdkeyType;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getUseConsumer() {
        return useConsumer;
    }

    public void setUseConsumer(Long useConsumer) {
        this.useConsumer = useConsumer;
    }

    public Long getContentId() {
        return contentId;
    }

    public void setContentId(Long contentId) {
        this.contentId = contentId;
    }

    public Integer getContentType() {
        return contentType;
    }

    public void setContentType(Integer contentType) {
        this.contentType = contentType;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getExtInfo() {
        return extInfo;
    }

    public void setExtInfo(String extInfo) {
        this.extInfo = extInfo;
    }

    public String getCdkey() {
        return cdkey;
    }

    public void setCdkey(String cdkey) {
        this.cdkey = cdkey;
    }

    public Integer getCdkeyMoney() {
        return cdkeyMoney;
    }

    public void setCdkeyMoney(Integer cdkeyMoney) {
        this.cdkeyMoney = cdkeyMoney;
    }

    public Integer getCdkeyUsed() {
        return cdkeyUsed;
    }

    public void setCdkeyUsed(Integer cdkeyUsed) {
        this.cdkeyUsed = cdkeyUsed;
    }

    public Integer getCdkeyGuide() {
        return cdkeyGuide;
    }

    public void setCdkeyGuide(Integer cdkeyGuide) {
        this.cdkeyGuide = cdkeyGuide;
    }

    public Integer getCdkeyType() {
        return cdkeyType;
    }

    public void setCdkeyType(Integer cdkeyType) {
        this.cdkeyType = cdkeyType;
    }
}

==> youtui-center-api-0.0.1.15-lichao2-20180802.014405-5-sources.jar: cn/com/duiba/tuia/youtui/center/api/dto/youtui/YoutuiCdkeyDto.java <==
package cn.com.duiba.tuia.youtui.center.api.dto.youtui;

import java.io.Serializable;
import java.util.Date;

/**
 *  趣晒的cdkey
 *  @author lichao 2018/7/24
 */
public class YoutuiCdkeyDto implements Serializable {

    //主键
    private Long id;

    //用户id
    private Long consumerId;

    //app使用的用户id
    private Long useConsumer;

    //内容id
    private Long contentId;

    //内容类型(0:活动 2:直投页 3:游戏)
    private Integer contentType;

    private Date gmtCreate;

    private Date gmtModified;

    private String extInfo;

    //cdkey邀请码
    private String cdkey;

    //cdkey所携带的金钱
    private Long cdkeyMoney;

    //cdkey是否被使用过0否，1是
    private Integer cdkeyUsed;

    //cdkey的是否需要引导0 不需要引导 1需要引导
    private Integer cdkeyGuide;

    //cdkey的类型0 回流(不可重复使用)
    private Integer cdkeyType;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getUseConsumer() {
        return useConsumer;
    }

    public void setUseConsumer(Long useConsumer) {
        this.useConsumer = useConsumer;
    }

    public Long getContentId() {
        return contentId;
    }

    public void setContentId(Long contentId) {
        this.contentId = contentId;
    }

    public Integer getContentType() {
        return contentType;
    }

    public void setContentType(Integer contentType) {
        this.contentType = contentType;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getExtInfo() {
        return extInfo;
    }

    public void setExtInfo(String extInfo) {
        this.extInfo = extInfo;
    }

    public String getCdkey() {
        return cdkey;
    }

    public void setCdkey(String cdkey) {
        this.cdkey = cdkey;
    }

    public Long getCdkeyMoney() {
        return cdkeyMoney;
    }

    public void setCdkeyMoney(Long cdkeyMoney) {
        this.cdkeyMoney = cdkeyMoney;
    }

    public Integer getCdkeyUsed() {
        return cdkeyUsed;
    }

    public void setCdkeyUsed(Integer cdkeyUsed) {
        this.cdkeyUsed = cdkeyUsed;
    }

    public Integer getCdkeyGuide() {
        return cdkeyGuide;
    }

    public void setCdkeyGuide(Integer cdkeyGuide) {
        this.cdkeyGuide = cdkeyGuide;
    }

    public Integer getCdkeyType() {
        return cdkeyType;
    }

    public void setCdkeyType(Integer cdkeyType) {
        this.cdkeyType = cdkeyType;
    }
}
